@@ -7,11 +7,11 @@ If objects are marked experimental they might change between minor versions.
 To override/modify tox behaviour via plugins see `tox.hookspec` and its use with pluggy.
 """
 import pluggy
-from pkg_resources import DistributionNotFound, get_distribution
 
 from . import exception
 from .constants import INFO, PIP, PYTHON
 from .hookspecs import hookspec
+from .version import __version__
 
 __all__ = (
     "__version__",  # tox version
@@ -28,11 +28,5 @@ __all__ = (
 
 hookimpl = pluggy.HookimplMarker("tox")
 
-try:
-    _full_version = get_distribution(__name__).version
-    __version__ = _full_version.split("+", 1)[0]
-except DistributionNotFound:
-    __version__ = "0.0.0.dev0"
-
 # NOTE: must come last due to circular import
-from .session import cmdline  # noqa
+from .session import cmdline  # isort:skip
