@@ -2,9 +2,12 @@
 
 They live in the tox namespace and can be accessed as tox.[NAMESPACE.]NAME
 """
+import os
 import re
 import sys
 
+_THIS_FILE = os.path.realpath(os.path.abspath(__file__))
+
 
 def _construct_default_factors(cpython_versions, pypy_versions, other_interpreters):
     default_factors = {"py": sys.executable, "py2": "python2", "py3": "python3"}
@@ -27,7 +30,6 @@ def _construct_default_factors(cpython_versions, pypy_versions, other_interprete
 
 class PYTHON:
     PY_FACTORS_RE = re.compile("^(?!py$)(py|pypy|jython)([2-9][0-9]?)?$")
-    PY_FACTORS_MAP = {"py": "python", "pypy": "pypy", "jython": "jython"}
     CPYTHON_VERSION_TUPLES = [(2, 7), (3, 4), (3, 5), (3, 6), (3, 7), (3, 8)]
     PYPY_VERSION_TUPLES = [(2, 7), (3, 5)]
     OTHER_PYTHON_INTERPRETERS = ["jython"]
@@ -76,3 +78,10 @@ class PIP:
     ]
     INSTALL_SHORT_OPTIONS_ARGUMENT = ["-{}".format(option) for option in SHORT_OPTIONS]
     INSTALL_LONG_OPTIONS_ARGUMENT = ["--{}".format(option) for option in LONG_OPTIONS]
+
+
+_HELP_DIR = os.path.join(os.path.dirname(_THIS_FILE), "helper")
+VERSION_QUERY_SCRIPT = os.path.join(_HELP_DIR, "get_version.py")
+SITE_PACKAGE_QUERY_SCRIPT = os.path.join(_HELP_DIR, "get_site_package_dir.py")
+BUILD_REQUIRE_SCRIPT = os.path.join(_HELP_DIR, "build_requires.py")
+BUILD_ISOLATED = os.path.join(_HELP_DIR, "build_isolated.py")
